@@ -31,8 +31,8 @@ games_list_supported_all() {
 	available_threads=$(nproc)
 	## Passing the --list-supported-games switch is not required,
 	## because $PLAYIT_OPTION_LIST_SUPPORTED_GAMES is already set.
-	printf '%s' "$scripts_list" | \
-		xargs --delimiter='\n' --max-args=1 --max-procs="$available_threads" sh | \
+	printf '%s' "$scripts_list" |
+		xargs --delimiter='\n' --max-args=1 --max-procs="$available_threads" sh |
 		sort --unique
 }
 
