@@ -75,8 +75,8 @@ option_variable() {
 	# As an exemple, the value of the option "output-dir" would be stored in the following variable:
 	# PLAYIT_OPTION_OUTPUT_DIR
 	printf 'PLAYIT_OPTION_%s' "$(
-		printf '%s' "$option_name" | \
-			sed 's/-/_/g' | \
+		printf '%s' "$option_name" |
+			sed 's/-/_/g' |
 			tr '[:lower:]' '[:upper:]'
 	)"
 }
@@ -95,8 +95,8 @@ option_variable_default() {
 	# As an exemple, the default value of the option "output-dir" would be stored in the following variable:
 	# PLAYIT_DEFAULT_OPTION_OUTPUT_DIR
 	printf 'PLAYIT_DEFAULT_OPTION_%s' "$(
-		printf '%s' "$option_name" | \
-			sed 's/-/_/g' | \
+		printf '%s' "$option_name" |
+			sed 's/-/_/g' |
 			tr '[:lower:]' '[:upper:]'
 	)"
 }
