@@ -101,7 +101,7 @@ package_is_included_in_packages_list() {
 	local packages_list
 	packages_list=$(packages_list)
 
-	printf '%s' "$packages_list" | \
+	printf '%s' "$packages_list" |
 		grep --quiet --fixed-strings --word-regexp "$package"
 }
 
@@ -170,7 +170,7 @@ package_id() {
 	fi
 
 	# Check that the id fits the format restrictions.
-	if ! printf '%s' "$package_id" | \
+	if ! printf '%s' "$package_id" |
 		grep --quiet --regexp='^[0-9a-z][-0-9a-z]\+[0-9a-z]$'
 	then
 		error_package_id_invalid "$package_id"
@@ -320,9 +320,9 @@ package_maintainer() {
 	fi
 
 	# Try to get a maintainer string from /etc/makepkg.conf.
-	if \
-		[ -r '/etc/makepkg.conf' ] \
-		&& grep --quiet '^PACKAGER=' '/etc/makepkg.conf'
+	if
+		[ -r '/etc/makepkg.conf' ] &&
+		grep --quiet '^PACKAGER=' '/etc/makepkg.conf'
 	then
 		if grep --quiet '^PACKAGER=".*"' '/etc/makepkg.conf'; then
 			maintainer=$(sed --silent 's/^PACKAGER="\(.*\)"/\1/p' '/etc/makepkg.conf')
