@@ -10,8 +10,8 @@ dependencies_list_generic() {
 	dependencies_generic=$(context_value "${package}_DEPS")
 
 	# Generic dependencies are deprecated for compatibility levels ≥ 2.30
-	if \
-		[ -n "$dependencies_generic" ] && \
+	if
+		[ -n "$dependencies_generic" ] &&
 		compatibility_level_is_at_least '2.30'
 	then
 		warning_deprecated_variable "${package}_DEPS" "${package}_DEPENDENCIES_xxx"
