@@ -84,8 +84,8 @@ wine_launcher_environment() {
 	## The `wineserver` command is only used by winetricks
 	local winetricks_verbs
 	winetricks_verbs=$(wine_winetricks_verbs)
-	if \
-		[ -n "$winetricks_verbs" ] || \
+	if
+		[ -n "$winetricks_verbs" ] ||
 		[ -n "${WINE_DIRECT3D_RENDERER:-}" ]
 	then
 		cat <<- 'EOF'
@@ -96,8 +96,8 @@ wine_launcher_environment() {
 		EOF
 	fi
 	## Include the path to the `regedit` command only if it is going to be used
-	if \
-		[ -n "${APP_REGEDIT:-}" ] || \
+	if
+		[ -n "${APP_REGEDIT:-}" ] ||
 		[ -n "${WINE_REGEDIT_PERSISTENT_KEYS:-}" ]
 	then
 		cat <<- 'EOF'
@@ -111,8 +111,8 @@ wine_launcher_environment() {
 	# Include the winetricks wrapper function only if it is going to be used
 	local winetricks_verbs
 	winetricks_verbs=$(wine_winetricks_verbs)
-	if \
-		[ -n "$winetricks_verbs" ] || \
+	if
+		[ -n "$winetricks_verbs" ] ||
 		[ -n "${WINE_DIRECT3D_RENDERER:-}" ]
 	then
 		cat <<- 'EOF'
