@@ -84,6 +84,9 @@ dependency_package_providing_library_gentoo() {
 		('libasound_module_'*'.so')
 			package_name='media-plugins/alsa-plugins'
 		;;
+		('libatk-bridge-2.0.so.0')
+			package_name='app-accessibility/at-spi2-core'
+		;;
 		('libatspi.so.0')
 			package_name='app-accessibility/at-spi2-core'
 		;;
@@ -151,6 +154,9 @@ dependency_package_providing_library_gentoo() {
 		('libdl.so.2')
 			package_name='sys-libs/glibc'
 		;;
+		('libdrm.so.2')
+			package_name='x11-libs/libdrm'
+		;;
 		('libEGL.so.1')
 			package_name='media-libs/libglvnd'
 		;;
@@ -177,6 +183,9 @@ dependency_package_providing_library_gentoo() {
 		('libfribidi.so.0')
 			package_name='dev-libs/fribidi'
 		;;
+		('libgbm.so.1')
+			package_name='media-libs/mesa'
+		;;
 		('libgcc_s.so.1')
 			package_name='sys-devel/gcc'
 		;;
@@ -535,6 +544,9 @@ dependency_package_providing_library_gentoo() {
 		('libXinerama.so.1')
 			package_name='x11-libs/libXinerama'
 		;;
+		('libxkbcommon.so.0')
+			package_name='x11-libs/libxkbcommon'
+		;;
 		('libxml2.so.2')
 			package_name='dev-libs/libxml2'
 		;;
@@ -630,6 +642,9 @@ dependency_package_providing_library_gentoo32() {
 		('libasound_module_'*'.so')
 			package_name='media-plugins/alsa-plugins[abi_x86_32]'
 		;;
+		('libatk-bridge-2.0.so.0')
+			package_name='app-accessibility/at-spi2-core[abi_x86_32]'
+		;;
 		('libatspi.so.0')
 			package_name='app-accessibility/at-spi2-core[abi_x86_32]'
 		;;
@@ -697,6 +712,9 @@ dependency_package_providing_library_gentoo32() {
 		('libdl.so.2')
 			package_name='sys-libs/glibc amd64? ( sys-libs/glibc[multilib] )'
 		;;
+		('libdrm.so.2')
+			package_name='x11-libs/libdrm[abi_x86_32]'
+		;;
 		('libEGL.so.1')
 			package_name='media-libs/libglvnd[abi_x86_32]'
 		;;
@@ -723,6 +741,9 @@ dependency_package_providing_library_gentoo32() {
 		('libfribidi.so.0')
 			package_name='dev-libs/fribidi[abi_x86_32]'
 		;;
+		('libgbm.so.1')
+			package_name='media-libs/mesa[abi_x86_32]'
+		;;
 		('libgcc_s.so.1')
 			package_name='sys-devel/gcc[abi_x86_32]'
 		;;
@@ -1081,6 +1102,9 @@ dependency_package_providing_library_gentoo32() {
 		('libXinerama.so.1')
 			package_name='x11-libs/libXinerama[abi_x86_32]'
 		;;
+		('libxkbcommon.so.0')
+			package_name='x11-libs/libxkbcommon[abi_x86_32]'
+		;;
 		('libxml2.so.2')
 			package_name='dev-libs/libxml2[abi_x86_32]'
 		;;
